@@ -8,6 +8,7 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  *
@@ -23,7 +24,7 @@ public class CanvasPixbuf extends CanvasItem {
 	 * Constructs an instance of CanvasPixbuf from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasPixbuf(int handle) {
+	CanvasPixbuf(Handle handle) {
 		super(handle);
 	}
 
@@ -34,11 +35,6 @@ public class CanvasPixbuf extends CanvasItem {
 		return new Type(gnome_canvas_pixbuf_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
 	native static final protected int gnome_canvas_pixbuf_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
