@@ -8,6 +8,7 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.VBox;
 /**
@@ -25,7 +26,7 @@ public class IconSelection extends VBox {
 	/**
 	 * Construct a new IconSelection from a handle to a native resource.
 	 */
-	public IconSelection(int handle) {
+	public IconSelection(Handle handle) {
 	    super(handle);
 	}
 	
@@ -82,21 +83,17 @@ public class IconSelection extends VBox {
 		return new Type(gnome_icon_selection_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_icon_selection_get_type();
-	native static final protected int gnome_icon_selection_new();
-	native static final protected void gnome_icon_selection_add_defaults(int gis);
-	native static final protected void gnome_icon_selection_add_directory(int gis, String dir);
-	native static final protected void gnome_icon_selection_show_icons(int gis);
-	native static final protected void gnome_icon_selection_clear(int gis, boolean notShown);
-	native static final protected String gnome_icon_selection_get_icon(int gis, boolean fullPath);
-	native static final protected void gnome_icon_selection_select_icon(int gis, String filename);
-	native static final protected void gnome_icon_selection_stop_loading(int gis);
-	native static final protected int gnome_icon_selection_get_gil(int gis);
-	native static final protected int gnome_icon_selection_get_box(int gis);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_icon_selection_new();
+	native static final protected void gnome_icon_selection_add_defaults(Handle gis);
+	native static final protected void gnome_icon_selection_add_directory(Handle gis, String dir);
+	native static final protected void gnome_icon_selection_show_icons(Handle gis);
+	native static final protected void gnome_icon_selection_clear(Handle gis, boolean notShown);
+	native static final protected String gnome_icon_selection_get_icon(Handle gis, boolean fullPath);
+	native static final protected void gnome_icon_selection_select_icon(Handle gis, String filename);
+	native static final protected void gnome_icon_selection_stop_loading(Handle gis);
+	native static final protected Handle gnome_icon_selection_get_gil(Handle gis);
+	native static final protected Handle gnome_icon_selection_get_box(Handle gis);
+
 }
