@@ -24,9 +24,7 @@ extern "C"
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_PopupMenu_gnome_1popup_1menu_1new (JNIEnv *env, 
     jclass cls, jobjectArray uiinfo) 
 {
-    GnomeUIInfo *uiinfo_g = 
-        (GnomeUIInfo*)getArrayFromHandles(env, uiinfo, 
-                                          sizeof(GnomeUIInfo), 1, 0);
+    GnomeUIInfo *uiinfo_g = (GnomeUIInfo*)getPointerArrayFromHandles(env, uiinfo);
     return getHandleFromPointer(env, gnome_popup_menu_new (uiinfo_g));
 }
 
@@ -37,9 +35,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_PopupMenu_gnome_1popup_1menu_1new (
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_PopupMenu_gnome_1popup_1menu_1new_1with_1accelgroup (
     JNIEnv *env, jclass cls, jobjectArray uiinfo, jobject accelgroup) 
 {
-    GnomeUIInfo *uiinfo_g = 
-        (GnomeUIInfo*)getArrayFromHandles(env, uiinfo, 
-                                          sizeof(GnomeUIInfo), 1, 0);
+    GnomeUIInfo *uiinfo_g = (GnomeUIInfo*)getPointerArrayFromHandles(env, uiinfo);
     GtkAccelGroup *accelgroup_g = (GtkAccelGroup *)getPointerFromHandle(env, accelgroup);
     return getHandleFromPointer(env, gnome_popup_menu_new_with_accelgroup (uiinfo_g, accelgroup_g));
 }
@@ -76,9 +72,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_PopupMenu_gnome_1popup_1menu_1append (
     jclass cls, jobject menu, jobjectArray uiinfo) 
 {
     GtkMenu *menu_g = (GtkMenu *)getPointerFromHandle(env, menu);
-    GnomeUIInfo *uiinfo_g = 
-        (GnomeUIInfo*)getArrayFromHandles(env, uiinfo, 
-                                          sizeof(GnomeUIInfo), 1, 0);
+    GnomeUIInfo *uiinfo_g = (GnomeUIInfo*)getPointerArrayFromHandles(env, uiinfo);
     gnome_popup_menu_append ((GtkWidget*)menu_g, uiinfo_g);
 }
 
